@@ -1,7 +1,8 @@
 context("Format methods")
 
 test_that("Idd formatting", {
-    testthat::skip_on_os("windows")
+    # only test on UTF-8 supported platform
+    testthat::skip_if_not(cli::is_utf8_output())
 
     # IDD {{{
     idd_parsed <- parse_idd_file(text("idd", "9.9.9"))
